@@ -123,6 +123,8 @@ class WorkspaceThumbnail extends St.Button {
             child: new Clutter.Actor({
                 layout_manager: new WorkspaceLayout(),
                 clip_to_allocation: true,
+                x_expand: true,
+                y_expand: true,
             }),
         });
 
@@ -263,7 +265,7 @@ class WorkspaceIndicator extends PanelMenu.Button {
             x_expand: true,
             y_expand: true,
         });
-        this.add_actor(container);
+        this.add_child(container);
 
         let workspaceManager = global.workspace_manager;
 
@@ -274,7 +276,7 @@ class WorkspaceIndicator extends PanelMenu.Button {
             text: this._labelText(),
         });
 
-        container.add_actor(this._statusLabel);
+        container.add_child(this._statusLabel);
 
         this._thumbnailsBox = new St.BoxLayout({
             style_class: 'panel-workspace-indicator-box',
@@ -282,7 +284,7 @@ class WorkspaceIndicator extends PanelMenu.Button {
             reactive: true,
         });
 
-        container.add_actor(this._thumbnailsBox);
+        container.add_child(this._thumbnailsBox);
 
         this._workspacesItems = [];
         this._workspaceSection = new PopupMenu.PopupMenuSection();
@@ -347,7 +349,7 @@ class WorkspaceIndicator extends PanelMenu.Button {
         for (let i = 0; i < this._workspacesItems.length; i++) {
             this._workspacesItems[i].setOrnament(i === this._currentWorkspace
                 ? PopupMenu.Ornament.DOT
-                : PopupMenu.Ornament.NONE);
+                : PopupMenu.Ornament.NO_DOT);
         }
     }
 
@@ -391,8 +393,9 @@ class WorkspaceIndicator extends PanelMenu.Button {
                 this._activate(actor.workspaceId);
             });
 
-            if (i === this._currentWorkspace)
-                this._workspacesItems[i].setOrnament(PopupMenu.Ornament.DOT);
+            this._workspacesItems[i].setOrnament(i === this._currentWorkspace
+                ? PopupMenu.Ornament.DOT
+                : PopupMenu.Ornament.NO_DOT);
         }
 
         this._statusLabel.set_text(this._labelText());
@@ -405,7 +408,7 @@ class WorkspaceIndicator extends PanelMenu.Button {
 
         for (let i = 0; i < workspaceManager.n_workspaces; i++) {
             let thumb = new WorkspaceThumbnail(i);
-            this._thumbnailsBox.add_actor(thumb);
+            this._thumbnailsBox.add_child(thumb);
         }
         this._updateActiveThumbnail();
     }
